==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/mobilenetwork/kotlin/inputs/HttpsServerCertificateArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.mobilenetwork.kotlin.inputs

import com.pulumi.azurenative.mobilenetwork.inputs.HttpsServerCertificateArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * HTTPS server certificate configuration.
 * @property certificateUrl The certificate URL, unversioned. For example: https://contosovault.vault.azure.net/certificates/ingress.
 */
public data class HttpsServerCertificateArgs(
    public val certificateUrl: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.mobilenetwork.inputs.HttpsServerCertificateArgs> {
    override fun toJava(): com.pulumi.azurenative.mobilenetwork.inputs.HttpsServerCertificateArgs =
        com.pulumi.azurenative.mobilenetwork.inputs.HttpsServerCertificateArgs.builder()
            .certificateUrl(certificateUrl.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [HttpsServerCertificateArgs].
 */
@PulumiTagMarker
public class HttpsServerCertificateArgsBuilder internal constructor() {
    private var certificateUrl: Output<String>? = null

    /**
     * @param value The certificate URL, unversioned. For example: https://contosovault.vault.azure.net/certificates/ingress.
     */
    @JvmName("enllghuiqurvutuv")
    public suspend fun certificateUrl(`value`: Output<String>) {
        this.certificateUrl = value
    }

    /**
     * @param value The certificate URL, unversioned. For example: https://contosovault.vault.azure.net/certificates/ingress.
     */
    @JvmName("pijyklsdhvwjmmmh")
    public suspend fun certificateUrl(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.certificateUrl = mapped
    }

    internal fun build(): HttpsServerCertificateArgs = HttpsServerCertificateArgs(
        certificateUrl = certificateUrl ?: throw PulumiNullFieldException("certificateUrl"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/mobilenetwork/kotlin/inputs/HttpsServerCertificateArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.mobilenetwork.kotlin.inputs

import com.pulumi.azurenative.mobilenetwork.inputs.HttpsServerCertificateArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * HTTPS server certificate configuration.
 * @property certificateUrl The certificate URL, unversioned. For example: https://contosovault.vault.azure.net/certificates/ingress.
 */
public data class HttpsServerCertificateArgs(
    public val certificateUrl: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.mobilenetwork.inputs.HttpsServerCertificateArgs> {
    override fun toJava(): com.pulumi.azurenative.mobilenetwork.inputs.HttpsServerCertificateArgs =
        com.pulumi.azurenative.mobilenetwork.inputs.HttpsServerCertificateArgs.builder()
            .certificateUrl(certificateUrl.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [HttpsServerCertificateArgs].
 */
@PulumiTagMarker
public class HttpsServerCertificateArgsBuilder internal constructor() {
    private var certificateUrl: Output<String>? = null

    /**
     * @param value The certificate URL, unversioned. For example: https://contosovault.vault.azure.net/certificates/ingress.
     */
    @JvmName("pqcdywasctdxojvu")
    public suspend fun certificateUrl(`value`: Output<String>) {
        this.certificateUrl = value
    }

    /**
     * @param value The certificate URL, unversioned. For example: https://contosovault.vault.azure.net/certificates/ingress.
     */
    @JvmName("aibwsilabukhsqnx")
    public suspend fun certificateUrl(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.certificateUrl = mapped
    }

    internal fun build(): HttpsServerCertificateArgs = HttpsServerCertificateArgs(
        certificateUrl = certificateUrl ?: throw PulumiNullFieldException("certificateUrl"),
    )
}
